@@ -8,14 +8,12 @@
 #include "crux-style.h"
 #include "crux-draw.h"
 
-#include "debug.h"
-
 
 GE_EXPORT void
 theme_init (GTypeModule *module)
 {
-  crux_rc_style_register_type (module);
-  crux_style_register_type (module);
+  crux_rc_style_register_types (module);
+  crux_style_register_types (module);
 }
 
 GE_EXPORT void
